#| -*-Scheme-*-

DO NOT EDIT: this file was generated by a program.

Copyright (C) 2020 Massachusetts Institute of Technology

This is free software; see the source for copying conditions. There is NO
warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

|#

;;;; Opcodes for SVM version 1

(declare (usual-integrations))

(make-rt-coding-type
 'address
 (list
  (make-rt-defn
   'indir
   1
   '(indirect (_ base word-register))
   (lambda (instance write-byte)
     (write-byte 1)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'offset-s8-b
   2
   '(offset (_ base word-register) (_ offset signed-8) byte)
   (lambda (instance write-byte)
     (write-byte 2)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'offset instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'offset-s8-w
   3
   '(offset (_ base word-register) (_ offset signed-8) word)
   (lambda (instance write-byte)
     (write-byte 3)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'offset instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'offset-s8-f
   4
   '(offset (_ base word-register) (_ offset signed-8) float)
   (lambda (instance write-byte)
     (write-byte 4)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'offset instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'offset-s16-b
   5
   '(offset (_ base word-register) (_ offset signed-16) byte)
   (lambda (instance write-byte)
     (write-byte 5)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'offset instance)
                               write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'offset-s16-w
   6
   '(offset (_ base word-register) (_ offset signed-16) word)
   (lambda (instance write-byte)
     (write-byte 6)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'offset instance)
                               write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'offset-s16-f
   7
   '(offset (_ base word-register) (_ offset signed-16) float)
   (lambda (instance write-byte)
     (write-byte 7)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'offset instance)
                               write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'offset-s32-b
   8
   '(offset (_ base word-register) (_ offset signed-32) byte)
   (lambda (instance write-byte)
     (write-byte 8)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'offset instance)
                               write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'offset-s32-w
   9
   '(offset (_ base word-register) (_ offset signed-32) word)
   (lambda (instance write-byte)
     (write-byte 9)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'offset instance)
                               write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'offset-s32-f
   10
   '(offset (_ base word-register) (_ offset signed-32) float)
   (lambda (instance write-byte)
     (write-byte 10)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'offset instance)
                               write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'index-b-b
   11
   '(indexed (_ base word-register)  (_ offset unsigned-8)
     byte    (_ index word-register) byte)
   (lambda (instance write-byte)
     (write-byte 11)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'offset instance)
                                write-byte)
     (encode-rref (rt-instance-pval 'index instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'index-b-w
   12
   '(indexed (_ base word-register)  (_ offset unsigned-8)
     byte    (_ index word-register) word)
   (lambda (instance write-byte)
     (write-byte 12)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'offset instance)
                                write-byte)
     (encode-rref (rt-instance-pval 'index instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'index-b-f
   13
   '(indexed (_ base word-register)  (_ offset unsigned-8)
     byte    (_ index word-register) float)
   (lambda (instance write-byte)
     (write-byte 13)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'offset instance)
                                write-byte)
     (encode-rref (rt-instance-pval 'index instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'index-w-b
   14
   '(indexed (_ base word-register)  (_ offset unsigned-8)
     word    (_ index word-register) byte)
   (lambda (instance write-byte)
     (write-byte 14)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'offset instance)
                                write-byte)
     (encode-rref (rt-instance-pval 'index instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'index-w-w
   15
   '(indexed (_ base word-register)  (_ offset unsigned-8)
     word    (_ index word-register) word)
   (lambda (instance write-byte)
     (write-byte 15)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'offset instance)
                                write-byte)
     (encode-rref (rt-instance-pval 'index instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'index-w-f
   16
   '(indexed (_ base word-register)  (_ offset unsigned-8)
     word    (_ index word-register) float)
   (lambda (instance write-byte)
     (write-byte 16)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'offset instance)
                                write-byte)
     (encode-rref (rt-instance-pval 'index instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'index-f-b
   17
   '(indexed (_ base word-register)  (_ offset unsigned-8)
     float   (_ index word-register) byte)
   (lambda (instance write-byte)
     (write-byte 17)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'offset instance)
                                write-byte)
     (encode-rref (rt-instance-pval 'index instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'index-f-w
   18
   '(indexed (_ base word-register)  (_ offset unsigned-8)
     float   (_ index word-register) word)
   (lambda (instance write-byte)
     (write-byte 18)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'offset instance)
                                write-byte)
     (encode-rref (rt-instance-pval 'index instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'index-f-f
   19
   '(indexed (_ base word-register)  (_ offset unsigned-8)
     float   (_ index word-register) float)
   (lambda (instance write-byte)
     (write-byte 19)
     (encode-rref (rt-instance-pval 'base instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'offset instance)
                                write-byte)
     (encode-rref (rt-instance-pval 'index instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'predec-b
   20
   '(pre-decrement (_ base word-register) byte)
   (lambda (instance write-byte)
     (write-byte 20)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'predec-w
   21
   '(pre-decrement (_ base word-register) word)
   (lambda (instance write-byte)
     (write-byte 21)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'predec-f
   22
   '(pre-decrement (_ base word-register) float)
   (lambda (instance write-byte)
     (write-byte 22)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'preinc-b
   23
   '(pre-increment (_ base word-register) byte)
   (lambda (instance write-byte)
     (write-byte 23)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'preinc-w
   24
   '(pre-increment (_ base word-register) word)
   (lambda (instance write-byte)
     (write-byte 24)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'preinc-f
   25
   '(pre-increment (_ base word-register) float)
   (lambda (instance write-byte)
     (write-byte 25)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'postdec-b
   26
   '(post-decrement (_ base word-register) byte)
   (lambda (instance write-byte)
     (write-byte 26)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'postdec-w
   27
   '(post-decrement (_ base word-register) word)
   (lambda (instance write-byte)
     (write-byte 27)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'postdec-f
   28
   '(post-decrement (_ base word-register) float)
   (lambda (instance write-byte)
     (write-byte 28)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'postinc-b
   29
   '(post-increment (_ base word-register) byte)
   (lambda (instance write-byte)
     (write-byte 29)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'postinc-w
   30
   '(post-increment (_ base word-register) word)
   (lambda (instance write-byte)
     (write-byte 30)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'postinc-f
   31
   '(post-increment (_ base word-register) float)
   (lambda (instance write-byte)
     (write-byte 31)
     (encode-rref (rt-instance-pval 'base instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'pcr-s8
   32
   '(pc-relative (_ value signed-8))
   (lambda (instance write-byte)
     (write-byte 32)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (list (decode-signed-integer-8 read-byte))))
  (make-rt-defn
   'pcr-s16
   33
   '(pc-relative (_ value signed-16))
   (lambda (instance write-byte)
     (write-byte 33)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (list (decode-signed-integer-16 read-byte))))
  (make-rt-defn
   'pcr-s32
   34
   '(pc-relative (_ value signed-32))
   (lambda (instance write-byte)
     (write-byte 34)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (list (decode-signed-integer-32 read-byte))))))

(make-rt-coding-type
 'instruction
 (list
  (make-rt-defn
   'store-b-wr-addr
   1
   '(store byte (_ source word-register) (_ target address))
   (lambda (instance write-byte)
     (write-byte 1)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (let ((pval (rt-instance-pval 'target instance)))
       ((rt-instance-encoder pval) pval write-byte)))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rt-coding-type 'address read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'store-w-wr-addr
   2
   '(store word (_ source word-register) (_ target address))
   (lambda (instance write-byte)
     (write-byte 2)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (let ((pval (rt-instance-pval 'target instance)))
       ((rt-instance-encoder pval) pval write-byte)))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rt-coding-type 'address read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'store-f-fr-addr
   3
   '(store float (_ source float-register) (_ target address))
   (lambda (instance write-byte)
     (write-byte 3)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (let ((pval (rt-instance-pval 'target instance)))
       ((rt-instance-encoder pval) pval write-byte)))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rt-coding-type 'address read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'load-b-wr-addr
   4
   '(load byte (_ target word-register) (_ source address))
   (lambda (instance write-byte)
     (write-byte 4)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (let ((pval (rt-instance-pval 'source instance)))
       ((rt-instance-encoder pval) pval write-byte)))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rt-coding-type 'address read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'load-w-wr-addr
   5
   '(load word (_ target word-register) (_ source address))
   (lambda (instance write-byte)
     (write-byte 5)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (let ((pval (rt-instance-pval 'source instance)))
       ((rt-instance-encoder pval) pval write-byte)))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rt-coding-type 'address read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'load-f-fr-addr
   6
   '(load float (_ target float-register) (_ source address))
   (lambda (instance write-byte)
     (write-byte 6)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (let ((pval (rt-instance-pval 'source instance)))
       ((rt-instance-encoder pval) pval write-byte)))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rt-coding-type 'address read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'load-address-addr
   7
   '(load-address (_ target word-register) (_ source address))
   (lambda (instance write-byte)
     (write-byte 7)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (let ((pval (rt-instance-pval 'source instance)))
       ((rt-instance-encoder pval) pval write-byte)))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rt-coding-type 'address read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'load-immediate-wr-s8
   8
   '(load-immediate (_ target word-register) (_ value-1 signed-8))
   (lambda (instance write-byte)
     (write-byte 8)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value-1 instance)
                              write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'load-immediate-wr-s16
   9
   '(load-immediate (_ target word-register) (_ value-1 signed-16))
   (lambda (instance write-byte)
     (write-byte 9)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value-1 instance)
                               write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'load-immediate-wr-s32
   10
   '(load-immediate (_ target word-register) (_ value-1 signed-32))
   (lambda (instance write-byte)
     (write-byte 10)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value-1 instance)
                               write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'load-immediate-fr-flt
   11
   '(load-immediate (_ target float-register) (_ value float))
   (lambda (instance write-byte)
     (write-byte 11)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-float (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-float read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'copy-block-u8-w
   12
   '(copy-block             (_ size unsigned-8)  word
     (_ from word-register) (_ to word-register))
   (lambda (instance write-byte)
     (write-byte 12)
     (encode-rref (rt-instance-pval 'to instance) write-byte)
     (encode-rref (rt-instance-pval 'from instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'size instance) write-byte))
   (lambda (read-byte)
     (let* ((v2 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v0 (decode-unsigned-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'copy-block-wr-w
   13
   '(copy-block             (_ size word-register) word
     (_ from word-register) (_ to word-register))
   (lambda (instance write-byte)
     (write-byte 13)
     (encode-rref (rt-instance-pval 'to instance) write-byte)
     (encode-rref (rt-instance-pval 'from instance) write-byte)
     (encode-rref (rt-instance-pval 'size instance) write-byte))
   (lambda (read-byte)
     (let* ((v2 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v0 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'load-non-pointer-tc-s8
   14
   '(load-non-pointer     (_ target word-register)
     (_ type-1 type-word) (_ value signed-8))
   (lambda (instance write-byte)
     (write-byte 14)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'type-1 instance)
                                write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'load-non-pointer-wr-s8
   15
   '(load-non-pointer         (_ target word-register)
     (_ source word-register) (_ value signed-8))
   (lambda (instance write-byte)
     (write-byte 15)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'load-non-pointer-tc-s16
   16
   '(load-non-pointer     (_ target word-register)
     (_ type-1 type-word) (_ value signed-16))
   (lambda (instance write-byte)
     (write-byte 16)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'type-1 instance)
                                write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'load-non-pointer-wr-s16
   17
   '(load-non-pointer         (_ target word-register)
     (_ source word-register) (_ value signed-16))
   (lambda (instance write-byte)
     (write-byte 17)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'load-non-pointer-tc-s32
   18
   '(load-non-pointer     (_ target word-register)
     (_ type-1 type-word) (_ value signed-32))
   (lambda (instance write-byte)
     (write-byte 18)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'type-1 instance)
                                write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'load-non-pointer-wr-s32
   19
   '(load-non-pointer         (_ target word-register)
     (_ source word-register) (_ value signed-32))
   (lambda (instance write-byte)
     (write-byte 19)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'load-non-pointer-tc-wr
   20
   '(load-non-pointer     (_ target word-register)
     (_ type-1 type-word) (_ datum word-register))
   (lambda (instance write-byte)
     (write-byte 20)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'type-1 instance)
                                write-byte)
     (encode-rref (rt-instance-pval 'datum instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'load-non-pointer
   21
   '(load-non-pointer         (_ target word-register)
     (_ source word-register) (_ datum word-register))
   (lambda (instance write-byte)
     (write-byte 21)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-rref (rt-instance-pval 'datum instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'load-pointer-tc-wr
   22
   '(load-pointer         (_ target word-register)
     (_ type-1 type-word) (_ address word-register))
   (lambda (instance write-byte)
     (write-byte 22)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'type-1 instance)
                                write-byte)
     (encode-rref (rt-instance-pval 'address instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'load-pointer
   23
   '(load-pointer             (_ target word-register)
     (_ source word-register) (_ address word-register))
   (lambda (instance write-byte)
     (write-byte 23)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-rref (rt-instance-pval 'address instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'jump-pcr-s8
   24
   '(jump (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 24)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (list (decode-signed-integer-8 read-byte))))
  (make-rt-defn
   'jump-pcr-s16
   25
   '(jump (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 25)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (list (decode-signed-integer-16 read-byte))))
  (make-rt-defn
   'jump-pcr-s32
   26
   '(jump (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 26)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (list (decode-signed-integer-32 read-byte))))
  (make-rt-defn
   'jump-indir-wr
   27
   '(jump (indirect (_ address word-register)))
   (lambda (instance write-byte)
     (write-byte 27)
     (encode-rref (rt-instance-pval 'address instance) write-byte))
   (lambda (read-byte)
     (list (decode-rref read-byte))))
  (make-rt-defn
   'ijump-u8
   28
   '(indirect-jump (pc-relative (_ value unsigned-8)))
   (lambda (instance write-byte)
     (write-byte 28)
     (encode-unsigned-integer-8 (rt-instance-pval 'value instance)
                                write-byte))
   (lambda (read-byte)
     (list (decode-unsigned-integer-8 read-byte))))
  (make-rt-defn
   'ijump-u16
   29
   '(indirect-jump (pc-relative (_ value unsigned-16)))
   (lambda (instance write-byte)
     (write-byte 29)
     (encode-unsigned-integer-16 (rt-instance-pval 'value instance)
                                 write-byte))
   (lambda (read-byte)
     (list (decode-unsigned-integer-16 read-byte))))
  (make-rt-defn
   'ijump-u32
   30
   '(indirect-jump (pc-relative (_ value unsigned-32)))
   (lambda (instance write-byte)
     (write-byte 30)
     (encode-unsigned-integer-32 (rt-instance-pval 'value instance)
                                 write-byte))
   (lambda (read-byte)
     (list (decode-unsigned-integer-32 read-byte))))
  (make-rt-defn
   'icall-u8
   31
   '(indirect-call (pc-relative (_ value unsigned-8)))
   (lambda (instance write-byte)
     (write-byte 31)
     (encode-unsigned-integer-8 (rt-instance-pval 'value instance)
                                write-byte))
   (lambda (read-byte)
     (list (decode-unsigned-integer-8 read-byte))))
  (make-rt-defn
   'icall-u16
   32
   '(indirect-call (pc-relative (_ value unsigned-16)))
   (lambda (instance write-byte)
     (write-byte 32)
     (encode-unsigned-integer-16 (rt-instance-pval 'value instance)
                                 write-byte))
   (lambda (read-byte)
     (list (decode-unsigned-integer-16 read-byte))))
  (make-rt-defn
   'icall-u32
   33
   '(indirect-call (pc-relative (_ value unsigned-32)))
   (lambda (instance write-byte)
     (write-byte 33)
     (encode-unsigned-integer-32 (rt-instance-pval 'value instance)
                                 write-byte))
   (lambda (read-byte)
     (list (decode-unsigned-integer-32 read-byte))))
  (make-rt-defn
   'enter-closure
   34
   '(enter-closure (_ index unsigned-16))
   (lambda (instance write-byte)
     (write-byte 34)
     (encode-unsigned-integer-16 (rt-instance-pval 'index instance)
                                 write-byte))
   (lambda (read-byte)
     (list (decode-unsigned-integer-16 read-byte))))
  (make-rt-defn
   'cjump-eq-wr-wr-pcr-s8
   35
   '(conditional-jump                 eq
     (_ source1 word-register)        (_ source2 word-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 35)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-neq-wr-wr-pcr-s8
   36
   '(conditional-jump                 neq
     (_ source1 word-register)        (_ source2 word-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 36)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-lt-wr-wr-pcr-s8
   37
   '(conditional-jump                 lt
     (_ source1 word-register)        (_ source2 word-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 37)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-ge-wr-wr-pcr-s8
   38
   '(conditional-jump                 ge
     (_ source1 word-register)        (_ source2 word-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 38)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-gt-wr-wr-pcr-s8
   39
   '(conditional-jump                 gt
     (_ source1 word-register)        (_ source2 word-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 39)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-le-wr-wr-pcr-s8
   40
   '(conditional-jump                 le
     (_ source1 word-register)        (_ source2 word-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 40)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-slt-wr-wr-pcr-s8
   41
   '(conditional-jump                 slt
     (_ source1 word-register)        (_ source2 word-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 41)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-sge-wr-wr-pcr-s8
   42
   '(conditional-jump                 sge
     (_ source1 word-register)        (_ source2 word-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 42)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-sgt-wr-wr-pcr-s8
   43
   '(conditional-jump                 sgt
     (_ source1 word-register)        (_ source2 word-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 43)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-sle-wr-wr-pcr-s8
   44
   '(conditional-jump                 sle
     (_ source1 word-register)        (_ source2 word-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 44)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-eq-wr-wr-pcr-s16
   45
   '(conditional-jump                  eq
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 45)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-neq-wr-wr-pcr-s16
   46
   '(conditional-jump                  neq
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 46)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-lt-wr-wr-pcr-s16
   47
   '(conditional-jump                  lt
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 47)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-ge-wr-wr-pcr-s16
   48
   '(conditional-jump                  ge
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 48)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-gt-wr-wr-pcr-s16
   49
   '(conditional-jump                  gt
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 49)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-le-wr-wr-pcr-s16
   50
   '(conditional-jump                  le
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 50)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-slt-wr-wr-pcr-s16
   51
   '(conditional-jump                  slt
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 51)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-sge-wr-wr-pcr-s16
   52
   '(conditional-jump                  sge
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 52)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-sgt-wr-wr-pcr-s16
   53
   '(conditional-jump                  sgt
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 53)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-sle-wr-wr-pcr-s16
   54
   '(conditional-jump                  sle
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 54)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-eq-wr-wr-pcr-s32
   55
   '(conditional-jump                  eq
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 55)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-neq-wr-wr-pcr-s32
   56
   '(conditional-jump                  neq
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 56)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-lt-wr-wr-pcr-s32
   57
   '(conditional-jump                  lt
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 57)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-ge-wr-wr-pcr-s32
   58
   '(conditional-jump                  ge
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 58)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-gt-wr-wr-pcr-s32
   59
   '(conditional-jump                  gt
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 59)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-le-wr-wr-pcr-s32
   60
   '(conditional-jump                  le
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 60)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-slt-wr-wr-pcr-s32
   61
   '(conditional-jump                  slt
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 61)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-sge-wr-wr-pcr-s32
   62
   '(conditional-jump                  sge
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 62)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-sgt-wr-wr-pcr-s32
   63
   '(conditional-jump                  sgt
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 63)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-sle-wr-wr-pcr-s32
   64
   '(conditional-jump                  sle
     (_ source1 word-register)         (_ source2 word-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 64)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-eq-wr-pcr-s8
   65
   '(conditional-jump         eq
     (_ source word-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 65)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-neq-wr-pcr-s8
   66
   '(conditional-jump         neq
     (_ source word-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 66)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-slt-wr-pcr-s8
   67
   '(conditional-jump         slt
     (_ source word-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 67)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-sge-wr-pcr-s8
   68
   '(conditional-jump         sge
     (_ source word-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 68)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-sgt-wr-pcr-s8
   69
   '(conditional-jump         sgt
     (_ source word-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 69)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-sle-wr-pcr-s8
   70
   '(conditional-jump         sle
     (_ source word-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 70)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-eq-wr-pcr-s16
   71
   '(conditional-jump         eq
     (_ source word-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 71)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-neq-wr-pcr-s16
   72
   '(conditional-jump         neq
     (_ source word-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 72)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-slt-wr-pcr-s16
   73
   '(conditional-jump         slt
     (_ source word-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 73)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-sge-wr-pcr-s16
   74
   '(conditional-jump         sge
     (_ source word-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 74)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-sgt-wr-pcr-s16
   75
   '(conditional-jump         sgt
     (_ source word-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 75)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-sle-wr-pcr-s16
   76
   '(conditional-jump         sle
     (_ source word-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 76)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-eq-wr-pcr-s32
   77
   '(conditional-jump         eq
     (_ source word-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 77)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-neq-wr-pcr-s32
   78
   '(conditional-jump         neq
     (_ source word-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 78)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-slt-wr-pcr-s32
   79
   '(conditional-jump         slt
     (_ source word-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 79)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-sge-wr-pcr-s32
   80
   '(conditional-jump         sge
     (_ source word-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 80)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-sgt-wr-pcr-s32
   81
   '(conditional-jump         sgt
     (_ source word-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 81)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-sle-wr-pcr-s32
   82
   '(conditional-jump         sle
     (_ source word-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 82)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-fix-wr-pcr-s8
   83
   '(conditional-jump         fix
     (_ source word-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 83)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-nfix-wr-pcr-s8
   84
   '(conditional-jump         nfix
     (_ source word-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 84)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-ifix-wr-pcr-s8
   85
   '(conditional-jump         ifix
     (_ source word-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 85)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-nifix-wr-pcr-s8
   86
   '(conditional-jump         nifix
     (_ source word-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 86)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-fix-wr-pcr-s16
   87
   '(conditional-jump         fix
     (_ source word-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 87)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-nfix-wr-pcr-s16
   88
   '(conditional-jump         nfix
     (_ source word-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 88)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-ifix-wr-pcr-s16
   89
   '(conditional-jump         ifix
     (_ source word-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 89)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-nifix-wr-pcr-s16
   90
   '(conditional-jump         nifix
     (_ source word-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 90)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-fix-wr-pcr-s32
   91
   '(conditional-jump         fix
     (_ source word-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 91)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-nfix-wr-pcr-s32
   92
   '(conditional-jump         nfix
     (_ source word-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 92)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-ifix-wr-pcr-s32
   93
   '(conditional-jump         ifix
     (_ source word-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 93)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-nifix-wr-pcr-s32
   94
   '(conditional-jump         nifix
     (_ source word-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 94)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-eq-fr-fr-pcr-s8
   95
   '(conditional-jump                 eq
     (_ source1 float-register)       (_ source2 float-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 95)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-neq-fr-fr-pcr-s8
   96
   '(conditional-jump                 neq
     (_ source1 float-register)       (_ source2 float-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 96)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-lt-fr-fr-pcr-s8
   97
   '(conditional-jump                 lt
     (_ source1 float-register)       (_ source2 float-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 97)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-gt-fr-fr-pcr-s8
   98
   '(conditional-jump                 gt
     (_ source1 float-register)       (_ source2 float-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 98)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-le-fr-fr-pcr-s8
   99
   '(conditional-jump                 le
     (_ source1 float-register)       (_ source2 float-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 99)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-ge-fr-fr-pcr-s8
   100
   '(conditional-jump                 ge
     (_ source1 float-register)       (_ source2 float-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 100)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-cmp-fr-fr-pcr-s8
   101
   '(conditional-jump                 cmp
     (_ source1 float-register)       (_ source2 float-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 101)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-ncmp-fr-fr-pcr-s8
   102
   '(conditional-jump                 ncmp
     (_ source1 float-register)       (_ source2 float-register)
     (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 102)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-8 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-eq-fr-fr-pcr-s16
   103
   '(conditional-jump                  eq
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 103)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-neq-fr-fr-pcr-s16
   104
   '(conditional-jump                  neq
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 104)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-lt-fr-fr-pcr-s16
   105
   '(conditional-jump                  lt
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 105)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-gt-fr-fr-pcr-s16
   106
   '(conditional-jump                  gt
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 106)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-le-fr-fr-pcr-s16
   107
   '(conditional-jump                  le
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 107)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-ge-fr-fr-pcr-s16
   108
   '(conditional-jump                  ge
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 108)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-cmp-fr-fr-pcr-s16
   109
   '(conditional-jump                  cmp
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 109)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-ncmp-fr-fr-pcr-s16
   110
   '(conditional-jump                  ncmp
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 110)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-16 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-eq-fr-fr-pcr-s32
   111
   '(conditional-jump                  eq
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 111)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-neq-fr-fr-pcr-s32
   112
   '(conditional-jump                  neq
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 112)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-lt-fr-fr-pcr-s32
   113
   '(conditional-jump                  lt
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 113)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-gt-fr-fr-pcr-s32
   114
   '(conditional-jump                  gt
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 114)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-le-fr-fr-pcr-s32
   115
   '(conditional-jump                  le
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 115)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-ge-fr-fr-pcr-s32
   116
   '(conditional-jump                  ge
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 116)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-cmp-fr-fr-pcr-s32
   117
   '(conditional-jump                  cmp
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 117)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-ncmp-fr-fr-pcr-s32
   118
   '(conditional-jump                  ncmp
     (_ source1 float-register)        (_ source2 float-register)
     (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 118)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-signed-integer-32 read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'cjump-eq-fr-pcr-s8
   119
   '(conditional-jump          eq
     (_ source float-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 119)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-neq-fr-pcr-s8
   120
   '(conditional-jump          neq
     (_ source float-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 120)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-lt-fr-pcr-s8
   121
   '(conditional-jump          lt
     (_ source float-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 121)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-gt-fr-pcr-s8
   122
   '(conditional-jump          gt
     (_ source float-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 122)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-le-fr-pcr-s8
   123
   '(conditional-jump          le
     (_ source float-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 123)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-ge-fr-pcr-s8
   124
   '(conditional-jump          ge
     (_ source float-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 124)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-cmp-fr-pcr-s8
   125
   '(conditional-jump          cmp
     (_ source float-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 125)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-ncmp-fr-pcr-s8
   126
   '(conditional-jump          ncmp
     (_ source float-register) (pc-relative (_ value signed-8)))
   (lambda (instance write-byte)
     (write-byte 126)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-eq-fr-pcr-s16
   127
   '(conditional-jump          eq
     (_ source float-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 127)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-neq-fr-pcr-s16
   128
   '(conditional-jump          neq
     (_ source float-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 128)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-lt-fr-pcr-s16
   129
   '(conditional-jump          lt
     (_ source float-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 129)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-gt-fr-pcr-s16
   130
   '(conditional-jump          gt
     (_ source float-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 130)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-le-fr-pcr-s16
   131
   '(conditional-jump          le
     (_ source float-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 131)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-ge-fr-pcr-s16
   132
   '(conditional-jump          ge
     (_ source float-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 132)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-cmp-fr-pcr-s16
   133
   '(conditional-jump          cmp
     (_ source float-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 133)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-ncmp-fr-pcr-s16
   134
   '(conditional-jump          ncmp
     (_ source float-register) (pc-relative (_ value signed-16)))
   (lambda (instance write-byte)
     (write-byte 134)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-eq-fr-pcr-s32
   135
   '(conditional-jump          eq
     (_ source float-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 135)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-neq-fr-pcr-s32
   136
   '(conditional-jump          neq
     (_ source float-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 136)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-lt-fr-pcr-s32
   137
   '(conditional-jump          lt
     (_ source float-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 137)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-gt-fr-pcr-s32
   138
   '(conditional-jump          gt
     (_ source float-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 138)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-le-fr-pcr-s32
   139
   '(conditional-jump          le
     (_ source float-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 139)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-ge-fr-pcr-s32
   140
   '(conditional-jump          ge
     (_ source float-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 140)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-cmp-fr-pcr-s32
   141
   '(conditional-jump          cmp
     (_ source float-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 141)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cjump-ncmp-fr-pcr-s32
   142
   '(conditional-jump          ncmp
     (_ source float-register) (pc-relative (_ value signed-32)))
   (lambda (instance write-byte)
     (write-byte 142)
     (encode-rref (rt-instance-pval 'source instance) write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'value instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-signed-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'trap-trap-0
   143
   '(trap (_ code trap-0))
   (lambda (instance write-byte)
     (write-byte 143)
     (let ((pval (rt-instance-pval 'code instance)))
       ((rt-instance-encoder pval) pval write-byte)))
   (lambda (read-byte)
     (list (decode-rt-coding-type 'trap-0 read-byte))))
  (make-rt-defn
   'trap-trap-1-wr
   144
   '(trap (_ code trap-1) (_ arg0 word-register))
   (lambda (instance write-byte)
     (write-byte 144)
     (let ((pval (rt-instance-pval 'code instance)))
       ((rt-instance-encoder pval) pval write-byte))
     (encode-rref (rt-instance-pval 'arg0 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rt-coding-type 'trap-1 read-byte))
            (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'trap-trap-2-wr
   145
   '(trap (_ code trap-2) (_ arg0 word-register) (_ arg1 word-register))
   (lambda (instance write-byte)
     (write-byte 145)
     (let ((pval (rt-instance-pval 'code instance)))
       ((rt-instance-encoder pval) pval write-byte))
     (encode-rref (rt-instance-pval 'arg0 instance) write-byte)
     (encode-rref (rt-instance-pval 'arg1 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rt-coding-type 'trap-2 read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'trap-trap-3-wr
   146
   '(trap                   (_ code trap-3)        (_ arg0 word-register)
     (_ arg1 word-register) (_ arg2 word-register))
   (lambda (instance write-byte)
     (write-byte 146)
     (let ((pval (rt-instance-pval 'code instance)))
       ((rt-instance-encoder pval) pval write-byte))
     (encode-rref (rt-instance-pval 'arg0 instance) write-byte)
     (encode-rref (rt-instance-pval 'arg1 instance) write-byte)
     (encode-rref (rt-instance-pval 'arg2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rt-coding-type 'trap-3 read-byte))
            (v1 (decode-rref read-byte))
            (v2 (decode-rref read-byte))
            (v3 (decode-rref read-byte)))
       (list v0 v1 v2 v3))))
  (make-rt-defn 'interrupt-test-procedure
                147
                '(interrupt-test-procedure)
                (lambda (instance write-byte) instance (write-byte 147))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'interrupt-test-dynamic-link
                148
                '(interrupt-test-dynamic-link)
                (lambda (instance write-byte) instance (write-byte 148))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'interrupt-test-ic-procedure
                149
                '(interrupt-test-ic-procedure)
                (lambda (instance write-byte) instance (write-byte 149))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'interrupt-test-continuation
                150
                '(interrupt-test-continuation)
                (lambda (instance write-byte) instance (write-byte 150))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'pop-return
                151
                '(pop-return)
                (lambda (instance write-byte) instance (write-byte 151))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn
   'flonum-header-u8
   152
   '(flonum-header (_ target word-register) (_ value unsigned-8))
   (lambda (instance write-byte)
     (write-byte 152)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'value instance)
                                write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-8 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'flonum-header-u16
   153
   '(flonum-header (_ target word-register) (_ value unsigned-16))
   (lambda (instance write-byte)
     (write-byte 153)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-unsigned-integer-16 (rt-instance-pval 'value instance)
                                 write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-16 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'flonum-header-u32
   154
   '(flonum-header (_ target word-register) (_ value unsigned-32))
   (lambda (instance write-byte)
     (write-byte 154)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-unsigned-integer-32 (rt-instance-pval 'value instance)
                                 write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte))
            (v1 (decode-unsigned-integer-32 read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'flonum-header
   155
   '(flonum-header (_ target word-register) (_ n-elts word-register))
   (lambda (instance write-byte)
     (write-byte 155)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'n-elts instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'datum-u8
   #f
   '(datum-u8 (_ datum unsigned-8))
   (lambda (instance write-byte)
     (encode-unsigned-integer-8 (rt-instance-pval 'datum instance)
                                write-byte))
   (lambda (read-byte)
     (list (decode-unsigned-integer-8 read-byte))))
  (make-rt-defn
   'datum-u16
   #f
   '(datum-u16 (_ datum unsigned-16))
   (lambda (instance write-byte)
     (encode-unsigned-integer-16 (rt-instance-pval 'datum instance)
                                 write-byte))
   (lambda (read-byte)
     (list (decode-unsigned-integer-16 read-byte))))
  (make-rt-defn
   'datum-u32
   #f
   '(datum-u32 (_ datum unsigned-32))
   (lambda (instance write-byte)
     (encode-unsigned-integer-32 (rt-instance-pval 'datum instance)
                                 write-byte))
   (lambda (read-byte)
     (list (decode-unsigned-integer-32 read-byte))))
  (make-rt-defn
   'datum-s8
   #f
   '(datum-s8 (_ datum signed-8))
   (lambda (instance write-byte)
     (encode-signed-integer-8 (rt-instance-pval 'datum instance) write-byte))
   (lambda (read-byte)
     (list (decode-signed-integer-8 read-byte))))
  (make-rt-defn
   'datum-s16
   #f
   '(datum-s16 (_ datum signed-16))
   (lambda (instance write-byte)
     (encode-signed-integer-16 (rt-instance-pval 'datum instance) write-byte))
   (lambda (read-byte)
     (list (decode-signed-integer-16 read-byte))))
  (make-rt-defn
   'datum-s32
   #f
   '(datum-s32 (_ datum signed-32))
   (lambda (instance write-byte)
     (encode-signed-integer-32 (rt-instance-pval 'datum instance) write-byte))
   (lambda (read-byte)
     (list (decode-signed-integer-32 read-byte))))
  (make-rt-defn
   'copy-wr
   156
   '(copy (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 156)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'copy-fr
   157
   '(copy (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 157)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'negate-wr
   158
   '(negate (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 158)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'negate-fr
   159
   '(negate (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 159)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'increment-wr
   160
   '(increment (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 160)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'increment-fr
   161
   '(increment (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 161)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'decrement-wr
   162
   '(decrement (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 162)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'decrement-fr
   163
   '(decrement (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 163)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'abs-wr
   164
   '(abs (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 164)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'abs-fr
   165
   '(abs (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 165)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'object-type
   166
   '(object-type (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 166)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'object-datum
   167
   '(object-datum (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 167)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'object-address
   168
   '(object-address (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 168)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'fixnum->integer
   169
   '(fixnum->integer (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 169)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'integer->fixnum
   170
   '(integer->fixnum (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 170)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'not
   171
   '(not (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 171)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'flonum-align
   172
   '(flonum-align (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 172)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'flonum-length
   173
   '(flonum-length (_ target word-register) (_ source word-register))
   (lambda (instance write-byte)
     (write-byte 173)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'sqrt
   174
   '(sqrt (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 174)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'round
   175
   '(round (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 175)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'ceiling
   176
   '(ceiling (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 176)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'floor
   177
   '(floor (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 177)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'truncate
   178
   '(truncate (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 178)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'log
   179
   '(log (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 179)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'exp
   180
   '(exp (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 180)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'cos
   181
   '(cos (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 181)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'sin
   182
   '(sin (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 182)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'tan
   183
   '(tan (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 183)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'acos
   184
   '(acos (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 184)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'asin
   185
   '(asin (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 185)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   'atan
   186
   '(atan (_ target float-register) (_ source float-register))
   (lambda (instance write-byte)
     (write-byte 186)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte)))
       (list v0 v1))))
  (make-rt-defn
   '+-wr
   187
   '(+                         (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 187)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   '+-fr
   188
   '(+                          (_ target float-register)
     (_ source1 float-register) (_ source2 float-register))
   (lambda (instance write-byte)
     (write-byte 188)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   '--wr
   189
   '(-                         (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 189)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   '--fr
   190
   '(-                          (_ target float-register)
     (_ source1 float-register) (_ source2 float-register))
   (lambda (instance write-byte)
     (write-byte 190)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   '*-wr
   191
   '(*                         (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 191)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   '*-fr
   192
   '(*                          (_ target float-register)
     (_ source1 float-register) (_ source2 float-register))
   (lambda (instance write-byte)
     (write-byte 192)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'product
   193
   '(product                   (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 193)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'quotient
   194
   '(quotient                  (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 194)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'remainder
   195
   '(remainder                 (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 195)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'lsh
   196
   '(lsh                       (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 196)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'and
   197
   '(and                       (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 197)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'andc
   198
   '(andc                      (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 198)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'or
   199
   '(or                        (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 199)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'xor
   200
   '(xor                       (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 200)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'max-unsigned
   201
   '(max-unsigned              (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 201)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'min-unsigned
   202
   '(min-unsigned              (_ target word-register)
     (_ source1 word-register) (_ source2 word-register))
   (lambda (instance write-byte)
     (write-byte 202)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   '/
   203
   '(/                          (_ target float-register)
     (_ source1 float-register) (_ source2 float-register))
   (lambda (instance write-byte)
     (write-byte 203)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))
  (make-rt-defn
   'atan2
   204
   '(atan2                      (_ target float-register)
     (_ source1 float-register) (_ source2 float-register))
   (lambda (instance write-byte)
     (write-byte 204)
     (encode-rref (rt-instance-pval 'target instance) write-byte)
     (encode-rref (rt-instance-pval 'source1 instance) write-byte)
     (encode-rref (rt-instance-pval 'source2 instance) write-byte))
   (lambda (read-byte)
     (let* ((v0 (decode-rref read-byte)) (v1 (decode-rref read-byte))
                                         (v2 (decode-rref read-byte)))
       (list v0 v1 v2))))))

(make-rt-coding-type
 'trap-0
 (list
  (make-rt-defn 'add
                1
                'add
                (lambda (instance write-byte) instance (write-byte 1))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'decrement
                2
                'decrement
                (lambda (instance write-byte) instance (write-byte 2))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'divide
                3
                'divide
                (lambda (instance write-byte) instance (write-byte 3))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'equal?
                4
                'equal?
                (lambda (instance write-byte) instance (write-byte 4))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'greater?
                5
                'greater?
                (lambda (instance write-byte) instance (write-byte 5))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'increment
                6
                'increment
                (lambda (instance write-byte) instance (write-byte 6))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'less?
                7
                'less?
                (lambda (instance write-byte) instance (write-byte 7))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'modulo
                8
                'modulo
                (lambda (instance write-byte) instance (write-byte 8))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'multiply
                9
                'multiply
                (lambda (instance write-byte) instance (write-byte 9))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'negative?
                10
                'negative?
                (lambda (instance write-byte) instance (write-byte 10))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-1-0
                11
                'operator-1-0
                (lambda (instance write-byte) instance (write-byte 11))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-2-0
                12
                'operator-2-0
                (lambda (instance write-byte) instance (write-byte 12))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-2-1
                13
                'operator-2-1
                (lambda (instance write-byte) instance (write-byte 13))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-3-0
                14
                'operator-3-0
                (lambda (instance write-byte) instance (write-byte 14))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-3-1
                15
                'operator-3-1
                (lambda (instance write-byte) instance (write-byte 15))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-3-2
                16
                'operator-3-2
                (lambda (instance write-byte) instance (write-byte 16))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-4-0
                17
                'operator-4-0
                (lambda (instance write-byte) instance (write-byte 17))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-4-1
                18
                'operator-4-1
                (lambda (instance write-byte) instance (write-byte 18))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-4-2
                19
                'operator-4-2
                (lambda (instance write-byte) instance (write-byte 19))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-4-3
                20
                'operator-4-3
                (lambda (instance write-byte) instance (write-byte 20))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-apply
                21
                'operator-apply
                (lambda (instance write-byte) instance (write-byte 21))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-lexpr
                22
                'operator-lexpr
                (lambda (instance write-byte) instance (write-byte 22))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-lookup
                23
                'operator-lookup
                (lambda (instance write-byte) instance (write-byte 23))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'operator-primitive
                24
                'operator-primitive
                (lambda (instance write-byte) instance (write-byte 24))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'positive?
                25
                'positive?
                (lambda (instance write-byte) instance (write-byte 25))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'quotient
                26
                'quotient
                (lambda (instance write-byte) instance (write-byte 26))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'reflect-to-interface
                27
                'reflect-to-interface
                (lambda (instance write-byte) instance (write-byte 27))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'remainder
                28
                'remainder
                (lambda (instance write-byte) instance (write-byte 28))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'return-to-interpreter
                29
                'return-to-interpreter
                (lambda (instance write-byte) instance (write-byte 29))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'subtract
                30
                'subtract
                (lambda (instance write-byte) instance (write-byte 30))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'zero?
                31
                'zero?
                (lambda (instance write-byte) instance (write-byte 31))
                (lambda (read-byte) read-byte '()))))

(make-rt-coding-type
 'trap-1
 (list
  (make-rt-defn 'error
                1
                'error
                (lambda (instance write-byte) instance (write-byte 1))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'lookup
                2
                'lookup
                (lambda (instance write-byte) instance (write-byte 2))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'primitive-apply
                3
                'primitive-apply
                (lambda (instance write-byte) instance (write-byte 3))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'primitive-lexpr-apply
                4
                'primitive-lexpr-apply
                (lambda (instance write-byte) instance (write-byte 4))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'safe-lookup
                5
                'safe-lookup
                (lambda (instance write-byte) instance (write-byte 5))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'unassigned?
                6
                'unassigned?
                (lambda (instance write-byte) instance (write-byte 6))
                (lambda (read-byte) read-byte '()))))

(make-rt-coding-type
 'trap-2
 (list
  (make-rt-defn 'apply
                1
                'apply
                (lambda (instance write-byte) instance (write-byte 1))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'assignment
                2
                'assignment
                (lambda (instance write-byte) instance (write-byte 2))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'lexpr-apply
                3
                'lexpr-apply
                (lambda (instance write-byte) instance (write-byte 3))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'primitive-error
                4
                'primitive-error
                (lambda (instance write-byte) instance (write-byte 4))
                (lambda (read-byte) read-byte '()))))

(make-rt-coding-type
 'trap-3
 (list
  (make-rt-defn 'cache-reference-apply
                1
                'cache-reference-apply
                (lambda (instance write-byte) instance (write-byte 1))
                (lambda (read-byte) read-byte '()))
  (make-rt-defn 'link
                2
                'link
                (lambda (instance write-byte) instance (write-byte 2))
                (lambda (read-byte) read-byte '()))))